==> fluxbox-1.3.5.tar.xz: fluxbox-1.3.5/nls/fi_FI/generated-UTF-8.m <==
$ codeset=UTF-8

$set 1 #Align

1 Alas keskelle
2 Alas vasemmalle
3 Alas oikealle
4 Vaakasuoraan
5 Vasemmalle
6 Vasemmalle alas
7 Vasemmalle keskelle
8 Vasemmalle ylös
9 Suhteellisesti
10 Oikealle
11 Oikealle alas
12 Oikealle keskelle
13 Oikealle ylös
14 Ylös keskelle
15 Ylös vasemmalle
16 Ylös oikealle
17 Pystysuoraan

$set 2 #BaseDisplay

1 Keskeytetään... kirjoitetaan muistivedos\n
2 Suljetaan\n
3 %s:      signaali %d siepattu\n

$set 3 #Common

1 Alpha-arvo
2 Piilota automaattisesti
3 Käännetty
4 Käännetyt vaihtoehdot
5 Kääntäjä
6 Kääntäjän versio
7     init
8     keys
9      nls
10     menu
11    style
12 Oletukset
13 pois käytöstä
14 Virhe
15 Fluxbox versio
16 Peitä ikkunaa suurennettaessa
17 GIT Revisio
18 Näkyvissä
19 Tälle tyylille ei ole määritetty taustaa.\nHae lisätietoja käsikirjasta ja UKK:sta.

$set 4 #Configmenu

1 Kirjasinten pehmennys
2 Tuo ikkunat esiin automaattisesti
3 Tuo ikkunat esiin napsauttamalla
4 Valitse ikkuna napsauttamalla
5 Kehystä tilapäiset ikkunat
6 Vaihda työpöytää hiiren rullalla
7 Valitse ikkuna työpöytää vaihdettaessa
8 Ikkunan valitseminen
9 Valitse aina uudet ikkunat
10 Suurenna näytön kokoiseksi
11 Kuvien pehmennys
12 Näytä ikkunan sisältö siirrettäessä
14 Valitse ikkuna osoittamalla
15 Kiertävä työpöytälistaus
16 Pakota pseudo-läpinäkyvyys
17 Valikon alpha-arvo
18 Läpinäkyvyys
19 Valitun ikkunan alpha-arvo
20 Valitsemattoman ikkunan alpha-arvo
21 Välilehtien vaihtoehdot
22 Välilehdet otsikkopalkissa
23 Ulkoisten välilehtien leveys
24 Valitse välilehti napsauttamalla
25 Valitse välilehti osoittamalla

$set 5 #Ewmh

1 Vakava virhe: Muistia ei voitu varata EWMH:n asiakaslistaukselle

$set 6 #FbTkError

1 Varoitus! Korkeus > 3200, asetetaan Korkeus = 3200
2 Varoitus! Leveys > 3200, asetetaan Leveys = 3200
3 Varoitus: Varakirjaisinta ei voitu ladata
4 Varausvirhe.
5 Virhe rasterikuvaa luotaessa
6 XImagea ei voi luoda
7 Luku epäonnistui
8 Varoitus: Alphalle ei löytynyt kelvollista formaattia.
9 Varoitus: Alpha-kuvan luonti epäonnistui.
10 Varoitus: Alpha-rasterikuvan luonti epäonnistui.
11 Näytön (%d) alustus epäonnistui
12 Muisti loppui
13 Blue-puskurille ei voitu varata muistia.
14 Green-puskurille ei voitu varata muistia.
15 Red-puskurille ei voitu varata muistia.
16 Teemakomponentin lukeminen epäonnistui
17 Visual-arvo ei ole tuettujen arvojen joukossa
18 Asetetaan oletusarvo

$set 7 #Fluxbox

1 Resurssitiedoston nimi ei ole kelvollinen!
2 Group-tiedostoa ei voitu avata
3 Tietokantaa ei voitu ladata
4 Yritetään uudelleen
5 Varoitus! Ikkunaa ei voitu kiinnittää mihinkään näyttöön!
6 Hakemistoa %s ei voi luoda
7 Hallittavaa näyttöä ei saatavilla.\nVarmista ettei toinen ikkunointiohjelma ole käynnissä.
8 Virhe jäsennettäessä säännöllistä lauseketta
9 Vakava virhe! Fluxbox-luokasta voi olla vain yksi ilmentymä.
10 X-palvelimeen ei voitu yhdistää.\nKäynnistä X ennen Fluxboxia.
11 Varoitus: X-palvelin ei tue maa-asetustoa
12 Varoitus: Ei voitu asettaa maa-asetuston muokkaimia

$set 8 #Gnome

1 Vakava virhe: Muistia ei voitu varata Gnomen asiakaslistaukselle

$set 9 #Keys

1 Keys: Virhe rivillä
2 Keys: Näppäimistöpuun yhdistäminen epäonnistui!
3 Keys: Virheellinen näppäinarvo rivillä

$set 10 #Menu

1 Asetukset
2 Fluxboxin oletusvalikko
3 Poistu
4 Kuvakkeet
5 Taso
6 Näytöllä
7 Sijoittuminen
8 Uudelleenlataa asetukset
9 Uudelleenkäynnistys
10 Varoitus: Merkkausvirhe (tag)

$set 11 #Remember

1 Kehystys
2 Koko
3 Siirrä työalueelle
4 Taso
5 Muista käynnistettäessä
6 Sijoittuminen
7 Tallenna suljettaessa
8 Varjostus
9 Kiinnitys
10 Tuntematon apps-tiedoston avain
11 Työalue
12 Näyttö

$set 12 #Screen

1 BScreen::BScreen: virhe X-palvelinta haettaessa.\ntoinen ikkunointiohjelma on jo käynnissä näytöllä
2 W: %4d x H: %4d
3 BScreen::BScreen: hallitaan näyttöä %d käyttäen arvoja visual 0x%lx, depth %d\n

$set 13 #Slit

1 Appletit
2 Edellinen appletti
3 Seuraava appletti
4 Applettitelakan asento
5 Taso
6 Applettitelakka näytöllä
7 Applettitelakan sijoittaminen
8 Applettitelakka
9 Tallenna applettitelakan asetukset

$set 14 #Toolbar

1 Uudelleennimeä nykyinen työalue
2 Kuvakepalkin tila
3 Kaikki ikkunat
4 Kuvakkeet
5 Ei mikään
6 Työpöytä
7 Työaluekuvakkeet
8 Työkalupalkin taso
9 Työkalupalkki näytöllä
10 Työkalupalkin sijoittaminen
11 Työkalupalkki
12 Työkalupalkin leveys näytöllä prosentteina
13 Kello 24h
14 Kello 12h
15 Muuta kellonajan esitystapaa
16 Näytä kuvat
17 Ei kuvakkeita
18 Työalueet ilman kuvakkeita

$set 15 #Window

1 Nimeämätön

$set 16 #Windowmenu

1 Sulje
2 Pienennä
3 Valitse taso
4 Taustalle
5 Suurenna
6 Esille
7 Siirrä työalueelle
8 Varjosta
9 Kiinnitä
10 Pakota sulkeminen

$set 17 #Workspace

1 Työalue %d
2 Työalueet
3 Lisää työalue
4 Poista viimeinen työalue

$set 18 #fbsetroot

1 Virhe: käytä vähintään yhtä seuraavista valitsimista: -solid, -mod, -gradient\n
2 Rasterikuvaa ei voitu luoda, lopetetaan!
3 -display <string>        näyttö\n\
-mod <x> <y>             modula-kuvio\n\
-foreground, -fg <color> modula-taustaväri\n\
-background, -bg <color> modula-edustaväri\n\n\
-gradient <texture>      väriliu'un tekstuuri\n\
-from <color>            väriliu'un alkamisväri\n\
-to <color>              väriliu'un päättymisväri\n\n\
-solid <color>           yhtenäinen väri\n\n\
-help                    tulosta ainoastaan tämä ohje\n

$set 19 #main

1 virhe: '-display' vaatii määreen
2 Lisämuistin varaaminen epäonnistui
3 Epäonnistunut tyyppimuunnos
4 Arvoalueen ulkopuolella
5 Ajonaikainen virhe
6 Vakiopoikkeus
7 tuntematon virhe
8 virhe: '-log' vaatii määreen
9 Lokitiedosto
10 Kirjoittaudutaan
11 virhe: '-rc' vaatii määreen
12 virhe: '-screen' vaatii määreen
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\
Web-sivu: http://www.fluxbox.org/\n\n\
-display <string>\t\tmuuta $DISPLAY.\n\
-screen <all|int,int,int>\tsuorita vain määrätyillä näytöillä.\n\
-rc <string>\t\t\tkäytä vaihtoehtoista resurssitiedostoa.\n\
-version\t\t\ttulosta ainoastaan ohjelman versio.\n\
-info\t\t\t\tnäytä tietoja.\n\
-log <filename>\t\t\tkirjoita lokiin.\n\
-help\t\t\t\ttulosta vain tämä ohje.\n\n
14 varoitus: 'DISPLAY' ympäristömuuttujaa ei voitu asettaa

$set 20 #layers

1 Telakan päällä
2 Alin
3 Työalue
4 Telakka
5 Oletus
6 Ylin

==> fluxbox-1.3.7.tar.xz: fluxbox-1.3.7/nls/fi_FI/generated-UTF-8.m <==
$ codeset=UTF-8

$set 1 #Align

1 Alas keskelle
2 Alas vasemmalle
3 Alas oikealle
4 Vaakasuoraan
5 Vasemmalle
6 Vasemmalle alas
7 Vasemmalle keskelle
8 Vasemmalle ylös
9 Suhteellisesti
10 Oikealle
11 Oikealle alas
12 Oikealle keskelle
13 Oikealle ylös
14 Ylös keskelle
15 Ylös vasemmalle
16 Ylös oikealle
17 Pystysuoraan

$set 2 #BaseDisplay

1 Keskeytetään... kirjoitetaan muistivedos\n
2 Suljetaan\n
3 %s:      signaali %d siepattu\n

$set 3 #Common

1 Alpha-arvo
2 Piilota automaattisesti
3 Käännetty
4 Käännetyt vaihtoehdot
5 Kääntäjä
6 Kääntäjän versio
7        init
8        keys
9         nls
10       menu
20  windowmenu
11       style
12 Oletukset
13 pois käytöstä
14 Virhe
15 Fluxbox versio
16 Peitä ikkunaa suurennettaessa
17 GIT Revisio
18 Näkyvissä
19 Tälle tyylille ei ole määritetty taustaa.\nHae lisätietoja käsikirjasta ja UKK:sta.

$set 4 #Configmenu

1 Kirjasinten pehmennys
2 Tuo ikkunat esiin automaattisesti
3 Tuo ikkunat esiin napsauttamalla
4 Valitse ikkuna napsauttamalla
5 Kehystä tilapäiset ikkunat
6 Vaihda työpöytää hiiren rullalla
7 Valitse ikkuna työpöytää vaihdettaessa
8 Ikkunan valitseminen
9 Valitse aina uudet ikkunat
10 Suurenna näytön kokoiseksi
11 Kuvien pehmennys
12 Näytä ikkunan sisältö siirrettäessä
14 Valitse ikkuna osoittamalla
15 Kiertävä työpöytälistaus
16 Pakota pseudo-läpinäkyvyys
17 Valikon alpha-arvo
18 Läpinäkyvyys
19 Valitun ikkunan alpha-arvo
20 Valitsemattoman ikkunan alpha-arvo
21 Välilehtien vaihtoehdot
22 Välilehdet otsikkopalkissa
23 Ulkoisten välilehtien leveys
24 Valitse välilehti napsauttamalla
25 Valitse välilehti osoittamalla

$set 5 #Ewmh

1 Vakava virhe: Muistia ei voitu varata EWMH:n asiakaslistaukselle

$set 6 #FbTkError

1 Varoitus! Korkeus > 3200, asetetaan Korkeus = 3200
2 Varoitus! Leveys > 3200, asetetaan Leveys = 3200
3 Varoitus: Varakirjaisinta ei voitu ladata
4 Varausvirhe.
5 Virhe rasterikuvaa luotaessa
6 XImagea ei voi luoda
7 Luku epäonnistui
8 Varoitus: Alphalle ei löytynyt kelvollista formaattia.
9 Varoitus: Alpha-kuvan luonti epäonnistui.
10 Varoitus: Alpha-rasterikuvan luonti epäonnistui.
11 Näytön (%d) alustus epäonnistui
12 Muisti loppui
13 Blue-puskurille ei voitu varata muistia.
14 Green-puskurille ei voitu varata muistia.
15 Red-puskurille ei voitu varata muistia.
16 Teemakomponentin lukeminen epäonnistui
17 Visual-arvo ei ole tuettujen arvojen joukossa
18 Asetetaan oletusarvo

$set 7 #Fluxbox

1 Resurssitiedoston nimi ei ole kelvollinen!
2 Group-tiedostoa ei voitu avata
3 Tietokantaa ei voitu ladata
4 Yritetään uudelleen
5 Varoitus! Ikkunaa ei voitu kiinnittää mihinkään näyttöön!
6 Hakemistoa %s ei voi luoda
7 Hallittavaa näyttöä ei saatavilla.\nVarmista ettei toinen ikkunointiohjelma ole käynnissä.
8 Virhe jäsennettäessä säännöllistä lauseketta
9 Vakava virhe! Fluxbox-luokasta voi olla vain yksi ilmentymä.
10 X-palvelimeen ei voitu yhdistää.\nKäynnistä X ennen Fluxboxia.
11 Varoitus: X-palvelin ei tue maa-asetustoa
12 Varoitus: Ei voitu asettaa maa-asetuston muokkaimia

$set 8 #Gnome

1 Vakava virhe: Muistia ei voitu varata Gnomen asiakaslistaukselle

$set 9 #Keys

1 Keys: Virhe rivillä
2 Keys: Näppäimistöpuun yhdistäminen epäonnistui!
3 Keys: Virheellinen näppäinarvo rivillä

$set 10 #Menu

1 Asetukset
2 Fluxboxin oletusvalikko
3 Poistu
4 Kuvakkeet
5 Taso
6 Näytöllä
7 Sijoittuminen
8 Uudelleenlataa asetukset
9 Uudelleenkäynnistys
10 Varoitus: Merkkausvirhe (tag)

$set 11 #Remember

1 Kehystys
2 Koko
3 Siirrä työalueelle
4 Taso
5 Muista käynnistettäessä
6 Sijoittuminen
7 Tallenna suljettaessa
8 Varjostus
9 Kiinnitys
10 Tuntematon apps-tiedoston avain
11 Työalue
12 Näyttö

$set 12 #Screen

1 BScreen::BScreen: virhe X-palvelinta haettaessa.\ntoinen ikkunointiohjelma on jo käynnissä näytöllä
2 W: %4d x H: %4d
3 BScreen::BScreen: hallitaan näyttöä %d käyttäen arvoja visual 0x%lx, depth %d\n

$set 13 #Slit

1 Appletit
2 Edellinen appletti
3 Seuraava appletti
4 Applettitelakan asento
5 Taso
6 Applettitelakka näytöllä
7 Applettitelakan sijoittaminen
8 Applettitelakka
9 Tallenna applettitelakan asetukset

$set 14 #Toolbar

1 Uudelleennimeä nykyinen työalue
2 Kuvakepalkin tila
3 Kaikki ikkunat
4 Kuvakkeet
5 Ei mikään
6 Työpöytä
7 Työaluekuvakkeet
8 Työkalupalkin taso
9 Työkalupalkki näytöllä
10 Työkalupalkin sijoittaminen
11 Työkalupalkki
12 Työkalupalkin leveys näytöllä prosentteina
13 Kello 24h
14 Kello 12h
15 Muuta kellonajan esitystapaa
16 Näytä kuvat
17 Ei kuvakkeita
18 Työalueet ilman kuvakkeita

$set 15 #Window

1 Nimeämätön

$set 16 #Windowmenu

1 Sulje
2 Pienennä
3 Valitse taso
4 Taustalle
5 Suurenna
6 Esille
7 Siirrä työalueelle
8 Varjosta
9 Kiinnitä
10 Pakota sulkeminen

$set 17 #Workspace

1 Työalue %d
2 Työalueet
3 Lisää työalue
4 Poista viimeinen työalue

$set 18 #fbsetroot

1 Virhe: käytä vähintään yhtä seuraavista valitsimista: -solid, -mod, -gradient\n
2 Rasterikuvaa ei voitu luoda, lopetetaan!
3 -display <string>        näyttö\n\
-mod <x> <y>             modula-kuvio\n\
-foreground, -fg <color> modula-taustaväri\n\
-background, -bg <color> modula-edustaväri\n\n\
-gradient <texture>      väriliu'un tekstuuri\n\
-from <color>            väriliu'un alkamisväri\n\
-to <color>              väriliu'un päättymisväri\n\n\
-solid <color>           yhtenäinen väri\n\n\
-help                    tulosta ainoastaan tämä ohje\n

$set 19 #main

1 virhe: '-display' vaatii määreen
2 Lisämuistin varaaminen epäonnistui
3 Epäonnistunut tyyppimuunnos
4 Arvoalueen ulkopuolella
5 Ajonaikainen virhe
6 Vakiopoikkeus
7 tuntematon virhe
8 virhe: '-log' vaatii määreen
9 Lokitiedosto
10 Kirjoittaudutaan
11 virhe: '-rc' vaatii määreen
12 virhe: '-screen' vaatii määreen
13 Fluxbox %s: (c) %s Fluxbox Team\n\
Web-sivu: http://www.fluxbox.org/\n\n\
-display <string>\t\tmuuta $DISPLAY.\n\
-screen <all|int,int,int>\tsuorita vain määrätyillä näytöillä.\n\
-no-slit\t\t\tdo not provide a slit\n\
-no-toolbar\t\tdo not provide a toolbar\n\
-rc <string>\t\t\tkäytä vaihtoehtoista resurssitiedostoa.\n\
-version\t\t\ttulosta ainoastaan ohjelman versio.\n\
-info\t\t\t\tnäytä tietoja.\n\
-list-commands\t\t\tlist all valid key commands.\n\
-sync\t\t\t\tsynchronize with X server for debugging.\n\
-log <filename>\t\t\tkirjoita lokiin.\n\
-help\t\t\t\ttulosta vain tämä ohje.\n\n
14 varoitus: 'DISPLAY' ympäristömuuttujaa ei voitu asettaa

$set 20 #layers

1 Telakan päällä
2 Alin
3 Työalue
4 Telakka
5 Oletus
6 Ylin
